@@ -15,7 +15,7 @@
 
 QT_BEGIN_NAMESPACE
 
-Q_LOGGING_CATEGORY(lcRouter, "qt.httpserver.router")
+Q_STATIC_LOGGING_CATEGORY(lcRouter, "qt.httpserver.router")
 
 using namespace Qt::StringLiterals;
 
@@ -47,10 +47,10 @@ static const QHash<QMetaType, QString> defaultConverters = {
 /*!
     \class QHttpServerRouter
     \since 6.4
-    \brief Provides functions to bind a URL to a \c ViewHandler.
+    \brief Provides functions to bind a path to a \c ViewHandler.
     \inmodule QtHttpServer
 
-    QHttpServerRouter is a class to distribute http requests to their
+    QHttpServerRouter is a class to distribute HTTP requests to their
     respective handlers with a rule based system.
 
     You can register new \l{QHttpServerRouterRule}{QHttpServerRouterRules},
@@ -59,8 +59,8 @@ static const QHash<QMetaType, QString> defaultConverters = {
     handler gets the placeholders value as a \l QRegularExpressionMatch. The
     arguments can be of any type for which a \l{converters}{converter} is
     available. The handler creation can be simplified with
-    QHttpServerRouterRule::bindCaptured. A QHttpServerRouter instance must not
-    be modifed by its rules.
+    QHttpServerRouterRule::bindCaptured(). A QHttpServerRouter instance must
+    not be modifed by its rules.
 
     \note This is a low-level routing API for an HTTP server.
 
@@ -93,41 +93,24 @@ static const QHash<QMetaType, QString> defaultConverters = {
     Adds a new converter for \e Type that can be parsed with \a regexp, and
     returns \c true if this was successful, otherwise returns \c false. If
     successful, the registered type can be used as argument in handlers for
-    \l{QHttpServerRouterRule}. The regular expression will be used to parse the
-    path pattern of the rule.
+    \l{QHttpServerRouterRule}. The regular expression will be used to parse
+    the path pattern of the rule.
 
     If there is already a converter of type \e Type, that converter's regexp
     is replaced with \a regexp.
 
-    Minimal example:
-    \code
-    struct CustomArg {
-        int data = 10;
+    Custom converters can extend the available type conversions through the
+    \l QMetaType system.
 
-        CustomArg() {} ;
-        CustomArg(const QString &urlArg) : data(urlArg.toInt()) {}
-    };
-    Q_DECLARE_METATYPE(CustomArg);
+    Define a class with a QString constructor:
+    \snippet custom-converter/main.cpp Define class
 
-    QHttpServerRouter router;
-    router.addConverter<CustomArg>(u"[+-]?\\d+"));
+    To use a custom type with the \l{QHttpServer}{HTTP server}, register
+    it using this function and define a \l{QHttpServer::}{route} handler
+    using the new type:
+    \snippet custom-converter/main.cpp Add converter and route
 
-    auto pageView = [] (const CustomArg &customArg) {
-        qDebug("data: %d", customArg.data);
-    };
-    using ViewHandler = decltype(pageView);
-
-    auto rule = std::make_unique<QHttpServerRouterRule>(
-        "/<arg>/log",
-        [&router, &pageView] (QRegularExpressionMatch &match,
-                              const QHttpServerRequest &request,
-                              QHttpServerResponder &&responder) {
-        // Bind and call viewHandler with match's captured string and quint32:
-        QHttpServerRouterRule::bindCaptured(pageView, match)();
-    });
-
-    router.addRule<ViewHandler>(std::move(rule));
-    \endcode
+    \sa converters, clearConverters
 */
 
 /*! \fn template <typename ViewHandler, typename ViewTraits = QHttpServerRouterViewTraits<ViewHandler>> bool QHttpServerRouter::addRule(std::unique_ptr<QHttpServerRouterRule> rule)
@@ -136,7 +119,7 @@ static const QHash<QMetaType, QString> defaultConverters = {
     Returns a pointer to the new rule if successful or \c nullptr otherwise.
 
     Inside addRule, we determine ViewHandler arguments and generate a list of
-    their QMetaType::Type ids. Then we parse the URL and replace each \c <arg>
+    their QMetaType::Type ids. Then we parse the path and replace each \c <arg>
     with a regexp for its type from the list. The \a rule must not modify the
     QHttpServerRouter instance.
 
